// $Id: RuleAction.cc 3526 2006-09-12 07:32:21Z vern $

#include "config.h"

#include "RuleAction.h"
#include "RuleMatcher.h"
#include "Conn.h"
#include "Event.h"
#include "NetVar.h"
#include "DPM.h"
#include "PIA.h"

void RuleActionEvent::DoAction(const Rule* parent, RuleEndpointState* state,
				const u_char* data, int len)
	{
	if ( signature_match )
		{
		val_list* vl = new val_list;
		vl->append(rule_matcher->BuildRuleStateValue(parent, state));
		vl->append(new StringVal(msg));

		if ( data )
			vl->append(new StringVal(len, (const char*)data));
		else
			vl->append(new StringVal(""));

		mgr.QueueEvent(signature_match, vl);
		}
	}

void RuleActionEvent::PrintDebug()
	{
	fprintf(stderr, "	RuleActionEvent: |%s|\n", msg);
	}

RuleActionDPM::RuleActionDPM(const char* arg_analyzer)
	{
	analyzer = Analyzer::GetTag(arg_analyzer);
	if ( analyzer != AnalyzerTag::Error )
		dpm->ActivateSigs();
	}

void RuleActionDPM::PrintDebug()
	{
	fprintf(stderr, "|%s|\n", Analyzer::GetTagName(analyzer));
	}


void RuleActionEnable::DoAction(const Rule* parent, RuleEndpointState* state,
				const u_char* data, int len)
	{
	if ( state->PIA() )
		state->PIA()->ActivateAnalyzer(Analyzer(), parent);
	}

void RuleActionEnable::PrintDebug()
	{
	fprintf(stderr, "  RuleActionEnable: ");
	RuleActionDPM::PrintDebug();
	}

void RuleActionDisable::DoAction(const Rule* parent, RuleEndpointState* state,
					const u_char* data, int len)
	{
	if ( state->PIA() )
		state->PIA()->DeactivateAnalyzer(Analyzer());
	}

void RuleActionDisable::PrintDebug()
	{
	fprintf(stderr, "  RuleActionDisable: ");
	RuleActionDPM::PrintDebug();
	}
